%define short     ossec


Summary:          An Open Source HIDS
Name:             ossec-hids
Version:          2.4
Release:          1%{?dist}%{?pext}
License:          GPL
Group:            System Environment/Base
Source0:          http://www.%{short}.net/files/%{name}-%{version}.tar.gz
Source1:          %{name}.init
Patch0:           %{name}-2.2-build.patch
Patch1:           %{name}-2.4-config.patch
URL:              http://www.%{short}.net/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           Daniel B. Cid <dcid@ossec.net>
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
BuildRequires:    libprelude-devel openssl-devel zlib-devel
BuildRequires:    mysql-devel postgresql-devel

%description
OSSEC is a scalable, multi-platform, open source Host-based Intrusion Detection
System (HIDS). It has a powerful correlation and analysis engine, integrating
log analysis, file integrity checking, Windows registry monitoring, centralized
policy enforcement, rootkit detection, real-time alerting and active response.
It runs on most operating systems, including Linux, OpenBSD, FreeBSD, MacOS,
Solaris and Windows.

This package contains common files required for all packages.


%package          client
Summary:          The OSSEC client
Group:            System Environment/Daemons
Requires:         %{name} = %{version}-%{release}
Requires(post):   /sbin/chkconfig %{_sbindir}/alternatives
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service %{_sbindir}/alternatives
Conflicts:        %{name}-server

%description      client
This package contains the client/agent part of OSSEC, which should be installed
on every system to be monitored.


%package          log2db
Summary:          Write OSSEC alerts to database
Group:            System Environment/Daemons
Requires:         %{name}-server = %{version}-%{release}

%description      log2db
This package contains the database log daemon, which enables the OSSEC server
to write alerts to a MySQL or PostgreSQL database.


%package          server
Summary:          The OSSEC server
Group:            System Environment/Daemons
Requires:         %{name} = %{version}-%{release}
Requires:         expect
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
Requires(post):   /sbin/chkconfig %{_sbindir}/alternatives
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service %{_sbindir}/alternatives
Conflicts:        %{name}-client

%description      server
This package contains the server part of OSSEC, which should be installed on a
central machine for log collection and alerting.


%prep
%setup -q
%patch0 -p1
%patch1 -p1

# Prepare docs
%{__cp} src/agentlessd/README README.agentless
%{__cp} src/os_regex/README   README.regex

# Fix permissions
%{__chmod} -x {BUGS,CONFIG,CONTRIB,INSTALL,LICENSE,README*}
%{__chmod} -x doc/*.{config,txt} etc/templates/config/*.template


%build
# XXX: OSSEC expects to be installed in "/var/ossec". To make it FHS-compliant
#      would require certain code changes, and a complete removal of its chroot
#      functionality. Does FHS qualify enough to do that? I don't think so. -PP

pushd src
# Build server
%{__make} %{?_smp_mflags} \
	CPPFLAGS="${RPM_OPT_FLAGS} -fno-strict-aliasing" \
	setdb setprelude all build

# Build client
%{__make} %{?_smp_mflags} \
	CPPFLAGS="${RPM_OPT_FLAGS} -fno-strict-aliasing" \
	setagent all
popd

for FILE in manage_agents %{short}-syscheckd %{short}-logcollector; do
  %{__mv} -f bin/${FILE}   bin/${FILE}-server
  %{__cp} -f src/*/${FILE} bin/${FILE}-client
done

# Generate the ossec-init.conf template
echo "DIRECTORY=\"%{_localstatedir}/%{short}\"" >  %{short}-init-agent.conf
echo "VERSION=\"v%{version}\""                  >> %{short}-init-agent.conf
echo "DATE=\"`date --utc`\""                    >> %{short}-init-agent.conf

%{__cp} -f %{short}-init-agent.conf %{short}-init-server.conf

for TYPE in agent server; do
  echo "TYPE=\"${TYPE}\"" >> %{short}-init-${TYPE}.conf
done


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/%{short}/contrib
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/{log,run}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/active-response/bin
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/agentless
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc/shared
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/logs/{archives,alerts,firewall}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/queue/{agent-info,agentless,alerts,diff,fts,%{short},rids,rootcheck,syscheck}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/rules
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/stats
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/tmp
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/var/run
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/.ssh

# Install common files
%{__install} -m 0755 %{SOURCE1}                ${RPM_BUILD_ROOT}%{_initrddir}/%{name}

%{__install} -m 0644 %{short}-init-*.conf      ${RPM_BUILD_ROOT}%{_sysconfdir}

%{__install} -m 0755 bin/manage_agents*        ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
%{__install} -m 0755 bin/ossec*                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin

%{__install} -m 0644 etc/internal_options.conf ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc

pushd active-response
%{__install} -m 0755 *.sh                      ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/active-response/bin
popd

pushd src/rootcheck/db
%{__install} -m 0644 *.txt                     ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc/shared
popd

%{__ln_s}    -f      %{_localstatedir}/%{short}/etc     ${RPM_BUILD_ROOT}%{_sysconfdir}/%{short}
%{__ln_s}    -f      %{_localstatedir}/%{short}/logs    ${RPM_BUILD_ROOT}%{_localstatedir}/log/%{short}
%{__ln_s}    -f      %{_localstatedir}/%{short}/var/run ${RPM_BUILD_ROOT}%{_localstatedir}/run/%{short}

touch                ${RPM_BUILD_ROOT}%{_sysconfdir}/%{short}-init.conf
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin/manage_agents
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin/%{short}-control
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin/%{short}-logcollector
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin/%{short}-syscheckd
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc/client.keys
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc/localtime
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc/%{short}.conf
touch                ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/logs/%{short}.log

# Install client files
%{__install} -m 0644 etc/%{short}-agent.conf  ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc

pushd src/init
%{__install} -m 0755 %{short}-client.sh       ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
popd

# Install server files
%{__install} -m 0755 bin/syscheck_update      ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
%{__install} -m 0755 bin/clear_stats          ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
%{__install} -m 0755 bin/list_agents          ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
%{__install} -m 0755 bin/agent_control        ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
%{__install} -m 0755 bin/syscheck_control     ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
%{__install} -m 0755 bin/rootcheck_control    ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin

%{__install} -m 0644 etc/decoder.xml          ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc

%{__install} -m 0644 etc/%{short}-server.conf ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/etc

%{__cp}      -r      etc/rules/*              ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/rules

pushd src/agentlessd
%{__install} -m 0750 scripts/*                 ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/agentless
popd

pushd src/init
%{__install} -m 0755 %{short}-server.sh       ${RPM_BUILD_ROOT}%{_localstatedir}/%{short}/bin
popd

# Install contrib files
pushd contrib
%{__install} -m 0750 {config2xml,*.pl,*.sh}   ${RPM_BUILD_ROOT}%{_datadir}/%{short}/contrib
%{__install} -m 0640 *.{conf,pm,sql,txt}      ${RPM_BUILD_ROOT}%{_datadir}/%{short}/contrib
popd


%pre
if ! getent group  %{short} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r %{short}
fi
if ! getent passwd %{short} >/dev/null 2>&1; then
  /usr/sbin/useradd  -g %{short}      \
	-d %{_localstatedir}/%{short} \
	-c "OSSEC Service user"       \
	-r -s /sbin/nologin %{short}
fi
exit 0			# Always pass

%pre server
if ! getent passwd ossecm >/dev/null 2>&1; then
  /usr/sbin/useradd  -g %{short}      \
	-d %{_localstatedir}/%{short} \
	-c "OSSEC Mail user"          \
	-r -s /sbin/nologin ossecm
fi
if ! getent passwd ossecr >/dev/null 2>&1; then
  /usr/sbin/useradd  -g %{short}      \
	-d %{_localstatedir}/%{short} \
	-c "OSSEC Remote user"        \
	-r -s /sbin/nologin ossecr
fi
exit 0			# Always pass


%post client
%{_sbindir}/alternatives \
	--install %{_localstatedir}/%{short}/bin/%{short}-control      %{name}      \
		  %{_localstatedir}/%{short}/bin/%{short}-client.sh    10           \
	--slave   %{_localstatedir}/%{short}/bin/%{short}-logcollector %{name}-logc \
		  %{_localstatedir}/%{short}/bin/%{short}-logcollector-client       \
	--slave   %{_localstatedir}/%{short}/bin/%{short}-syscheckd    %{name}-sysc \
		  %{_localstatedir}/%{short}/bin/%{short}-syscheckd-client          \
	--slave   %{_localstatedir}/%{short}/bin/manage_agents         %{name}-magt \
		  %{_localstatedir}/%{short}/bin/manage_agents-client               \
	--slave   %{_localstatedir}/%{short}/etc/%{short}.conf         %{name}-conf \
		  %{_localstatedir}/%{short}/etc/%{short}-agent.conf                \
	--slave   %{_sysconfdir}/%{short}-init.conf                    %{name}-init \
		  %{_sysconfdir}/%{short}-init-agent.conf

/sbin/chkconfig --add %{name}

%post server
%{_sbindir}/alternatives \
	--install %{_localstatedir}/%{short}/bin/%{short}-control      %{name}      \
		  %{_localstatedir}/%{short}/bin/%{short}-server.sh    10           \
	--slave   %{_localstatedir}/%{short}/bin/%{short}-logcollector %{name}-logc \
		  %{_localstatedir}/%{short}/bin/%{short}-logcollector-server       \
	--slave   %{_localstatedir}/%{short}/bin/%{short}-syscheckd    %{name}-sysc \
		  %{_localstatedir}/%{short}/bin/%{short}-syscheckd-server          \
	--slave   %{_localstatedir}/%{short}/bin/manage_agents         %{name}-magt \
		  %{_localstatedir}/%{short}/bin/manage_agents-server               \
	--slave   %{_localstatedir}/%{short}/etc/%{short}.conf         %{name}-conf \
		  %{_localstatedir}/%{short}/etc/%{short}-server.conf               \
	--slave   %{_sysconfdir}/%{short}-init.conf                    %{name}-init \
		  %{_sysconfdir}/%{short}-init-server.conf

/sbin/chkconfig --add %{name}


%preun client
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{name} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi

%preun server
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{name} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{name}
fi


%postun client
if [ $1 -eq 0 ]; then	# Remove
  %{_sbindir}/alternatives --remove %{name} %{_localstatedir}/%{short}/bin/%{short}-client.sh
else			# Upgrade
  /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi

%postun log2db
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi

%postun server
if [ $1 -eq 0 ]; then	# Remove
  %{_sbindir}/alternatives --remove %{name} %{_localstatedir}/%{short}/bin/%{short}-server.sh
else			# Upgrade
  /sbin/service %{name} condrestart >/dev/null 2>&1 || :
fi


%triggerin -- glibc, %{_sysconfdir}/localtime
TIMECONF="%{_sysconfdir}/localtime"
[ -r ${TIMECONF} ] && %{__install} -m 0644 ${TIMECONF} %{_localstatedir}/%{short}/etc


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc BUGS CONFIG CONTRIB INSTALL LICENSE README*
%doc --parents doc/*.{config,txt}
%doc etc/templates/config
%{_sysconfdir}/%{short}
%{_localstatedir}/log/%{short}
%{_localstatedir}/run/%{short}

%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/active-response
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/active-response/bin
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/bin
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/etc
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/queue
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/var

%attr(770,root,%{short}) %dir %{_localstatedir}/%{short}/etc/shared
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/logs
%attr(770,%{short},%{short}) %dir %{_localstatedir}/%{short}/queue/%{short}
%attr(770,root,%{short}) %dir %{_localstatedir}/%{short}/var/run
%attr(700,%{short},%{short}) %dir %{_localstatedir}/%{short}/.ssh

%files client
%defattr(-,root,root)
%{_initrddir}/%{name}
%attr(644,root,root) %{_sysconfdir}/%{short}-init-agent.conf

%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/queue/alerts
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/queue/syscheck

%attr(775,root,%{short}) %dir %{_localstatedir}/%{short}/queue/rids

%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/etc/%{short}-agent.conf
%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/etc/internal_options.conf
%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/etc/shared/*.txt

%attr(755,root,%{short}) %{_localstatedir}/%{short}/active-response/bin/*.sh
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/manage_agents-client
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-client.sh
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-agentd
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-execd
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-logcollector-client
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-syscheckd-client

%attr(644,root,%{short}) %ghost %{_localstatedir}/%{short}/etc/localtime
%attr(640,root,%{short}) %config %ghost %{_localstatedir}/%{short}/etc/client.keys
%attr(664,%{short},%{short}) %config %ghost %{_localstatedir}/%{short}/logs/%{short}.log

%ghost %{_sysconfdir}/%{short}-init.conf
%ghost %{_localstatedir}/%{short}/bin/manage_agents
%ghost %{_localstatedir}/%{short}/bin/%{short}-control
%ghost %{_localstatedir}/%{short}/bin/%{short}-logcollector
%ghost %{_localstatedir}/%{short}/bin/%{short}-syscheckd
%ghost %{_localstatedir}/%{short}/etc/%{short}.conf

%files log2db
%defattr(-,root,root)
%doc src/os_dbd/{README,*.schema}
%{_datadir}/%{short}/contrib/ossec2mysql*
%{_datadir}/%{short}/contrib/ossecmysql.pm
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-dbd

%files server
%defattr(-,root,root)
%{_initrddir}/%{name}
%attr(644,root,root) %{_sysconfdir}/%{short}-init-server.conf
%dir %{_datadir}/%{short}
%dir %{_datadir}/%{short}/contrib
%{_datadir}/%{short}/contrib/add_localfile.sh
%{_datadir}/%{short}/contrib/compile_alerts.*
%{_datadir}/%{short}/contrib/config2xml
%{_datadir}/%{short}/contrib/ossec-batch-manager.pl
%{_datadir}/%{short}/contrib/ossec_report*
%{_datadir}/%{short}/contrib/ossectop.pl

%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/agentless
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/rules
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/rules/translated
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/rules/translated/pure_ftpd
%attr(550,root,%{short}) %dir %{_localstatedir}/%{short}/tmp

%attr(755,ossecr,%{short}) %dir %{_localstatedir}/%{short}/queue/agent-info
%attr(755,%{short},%{short}) %dir %{_localstatedir}/%{short}/queue/agentless
%attr(770,%{short},%{short}) %dir %{_localstatedir}/%{short}/queue/alerts
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/queue/diff
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/queue/fts
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/logs/alerts
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/logs/archives
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/logs/firewall
%attr(755,ossecr,%{short}) %dir %{_localstatedir}/%{short}/queue/rids
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/queue/rootcheck
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/queue/syscheck
%attr(750,%{short},%{short}) %dir %{_localstatedir}/%{short}/stats

%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/etc/decoder.xml
%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/etc/internal_options.conf
%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/etc/%{short}-server.conf
%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/etc/shared/*.txt
%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/rules/*.xml
%attr(640,root,%{short}) %config(noreplace) %{_localstatedir}/%{short}/rules/translated/pure_ftpd/*.xml

%attr(750,root,%{short}) %{_localstatedir}/%{short}/agentless/*
%attr(755,root,%{short}) %{_localstatedir}/%{short}/active-response/bin/*.sh
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/agent_control
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/clear_stats
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/list_agents
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/manage_agents-server
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-server.sh
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-agentlessd
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-analysisd
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-csyslogd
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-execd
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-logcollector-server
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-logtest
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-maild
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-monitord
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-remoted
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-reportd
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/%{short}-syscheckd-server
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/rootcheck_control
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/syscheck_control
%attr(750,root,%{short}) %{_localstatedir}/%{short}/bin/syscheck_update

%attr(644,root,%{short}) %ghost %{_localstatedir}/%{short}/etc/localtime
%attr(640,root,%{short}) %config %ghost %{_localstatedir}/%{short}/etc/client.keys
%attr(664,%{short},%{short}) %config %ghost %{_localstatedir}/%{short}/logs/%{short}.log

%ghost %{_sysconfdir}/%{short}-init.conf
%ghost %{_localstatedir}/%{short}/bin/manage_agents
%ghost %{_localstatedir}/%{short}/bin/%{short}-control
%ghost %{_localstatedir}/%{short}/bin/%{short}-logcollector
%ghost %{_localstatedir}/%{short}/bin/%{short}-syscheckd
%ghost %{_localstatedir}/%{short}/etc/%{short}.conf


%changelog
* Fri Apr 16 2010 Peter Pramberger <peterpramb@member.fsf.org> - 2.4-1
- New version (2.4)

* Fri Dec 18 2009 Peter Pramberger <peterpramb@member.fsf.org> - 2.3-1
- New version (2.3)

* Sat Sep 26 2009 Peter Pramberger <peterpramb@member.fsf.org> - 2.2-1
- Upgrade version (2.2)
- Rewritten for buildsystem

* Wed Aug 29 2007 peter.pramberger@member.fsf.org 1.3-8
- fixed directory permissions (Siamak Hadinia)

* Mon Aug 20 2007 peter.pramberger@member.fsf.org 1.3-7
- new version (1.3)

* Wed May 23 2007 peter.pramberger@member.fsf.org 1.2-7
- new version (1.2)

* Thu May 03 2007 peter.pramberger@member.fsf.org 1.1-7
- new version (1.1)

* Mon Feb 26 2007 peter.pramberger@member.fsf.org 1.0-7
- new version (1.0)

* Thu Nov 02 2006 peter.pramberger@member.fsf.org 0.9.3-7
- new version (0.9-3)

* Fri Sep 29 2006 peter.pramberger@member.fsf.org
- new version (0.9-2)

* Thu Sep 07 2006 peter.pramberger@member.fsf.org
- new version (0.9-1a)

* Thu Aug 24 2006 peter.pramberger@member.fsf.org
- new version (0.9-1)

* Wed Jul 26 2006 peter.pramberger@member.fsf.org
- new version (0.9)

* Fri Jul 14 2006 peter.pramberger@member.fsf.org
- some bugfixes

* Fri Jul 07 2006 peter.pramberger@member.fsf.org
- created
